# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/data/feature_view.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tecton_proto.args import pipeline_pb2 as tecton__proto_dot_args_dot_pipeline__pb2
from tecton_proto.args import virtual_data_source_pb2 as tecton__proto_dot_args_dot_virtual__data__source__pb2
from tecton_proto.args import feature_view_pb2 as tecton__proto_dot_args_dot_feature__view__pb2
from tecton_proto.data import entity_pb2 as tecton__proto_dot_data_dot_entity__pb2
from tecton_proto.common import aggregation_function_pb2 as tecton__proto_dot_common_dot_aggregation__function__pb2
from tecton_proto.data import virtual_data_source_pb2 as tecton__proto_dot_data_dot_virtual__data__source__pb2
from tecton_proto.data import fv_materialization_pb2 as tecton__proto_dot_data_dot_fv__materialization__pb2
from tecton_proto.common import schema_pb2 as tecton__proto_dot_common_dot_schema__pb2
from tecton_proto.data import new_transformation_pb2 as tecton__proto_dot_data_dot_new__transformation__pb2
from tecton_proto.data import fco_metadata_pb2 as tecton__proto_dot_data_dot_fco__metadata__pb2
from tecton_proto.common import id_pb2 as tecton__proto_dot_common_dot_id__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/data/feature_view.proto',
  package='tecton_proto.data',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.dataP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$tecton_proto/data/feature_view.proto\x12\x11tecton_proto.data\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a tecton_proto/args/pipeline.proto\x1a+tecton_proto/args/virtual_data_source.proto\x1a$tecton_proto/args/feature_view.proto\x1a\x1etecton_proto/data/entity.proto\x1a.tecton_proto/common/aggregation_function.proto\x1a+tecton_proto/data/virtual_data_source.proto\x1a*tecton_proto/data/fv_materialization.proto\x1a tecton_proto/common/schema.proto\x1a*tecton_proto/data/new_transformation.proto\x1a$tecton_proto/data/fco_metadata.proto\x1a\x1ctecton_proto/common/id.proto\"\xc2\x0b\n\x0b\x46\x65\x61tureView\x12?\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\rfeatureViewId\x12\x41\n\x0c\x66\x63o_metadata\x18\x02 \x01(\x0b\x32\x1e.tecton_proto.data.FcoMetadataR\x0b\x66\x63oMetadata\x12\x36\n\nentity_ids\x18\x03 \x03(\x0b\x32\x17.tecton_proto.common.IdR\tentityIds\x12\x1b\n\tjoin_keys\x18\x04 \x03(\tR\x08joinKeys\x12?\n\x07schemas\x18\x0b \x01(\x0b\x32%.tecton_proto.data.FeatureViewSchemasR\x07schemas\x12P\n\x0b\x65nrichments\x18\xe8\x07 \x01(\x0b\x32).tecton_proto.data.FeatureViewEnrichmentsB\x02\x18\x01R\x0b\x65nrichments\x12X\n\x12temporal_aggregate\x18\x07 \x01(\x0b\x32\'.tecton_proto.data.NewTemporalAggregateH\x00R\x11temporalAggregate\x12<\n\x08temporal\x18\x08 \x01(\x0b\x32\x1e.tecton_proto.data.NewTemporalH\x00R\x08temporal\x12]\n\x16on_demand_feature_view\x18\x11 \x01(\x0b\x32&.tecton_proto.data.OnDemandFeatureViewH\x00R\x13onDemandFeatureView\x12\x46\n\rfeature_table\x18\x10 \x01(\x0b\x32\x1f.tecton_proto.data.FeatureTableH\x00R\x0c\x66\x65\x61tureTable\x12#\n\rtimestamp_key\x18\n \x01(\tR\x0ctimestampKey\x12W\n\x14online_serving_index\x18\x05 \x01(\x0b\x32%.tecton_proto.data.OnlineServingIndexR\x12onlineServingIndex\x12\x37\n\x08pipeline\x18\x06 \x01(\x0b\x32\x1b.tecton_proto.args.PipelineR\x08pipeline\x12\x62\n\x16materialization_params\x18\t \x01(\x0b\x32+.tecton_proto.data.NewMaterializationParamsR\x15materializationParams\x12\x37\n\x17materialization_enabled\x18\x0c \x01(\x08R\x16materializationEnabled\x12}\n!materialization_state_transitions\x18\r \x03(\x0b\x32\x31.tecton_proto.data.MaterializationStateTransitionR\x1fmaterializationStateTransitions\x12P\n\x11monitoring_params\x18\x0e \x01(\x0b\x32#.tecton_proto.data.MonitoringParamsR\x10monitoringParams\x12?\n\x1c\x66\x65\x61ture_store_format_version\x18\x17 \x01(\x05R\x19\x66\x65\x61tureStoreFormatVersion\x12G\n\x0esnowflake_data\x18\x18 \x01(\x0b\x32 .tecton_proto.data.SnowflakeDataR\rsnowflakeData\x12+\n\x11\x66ramework_version\x18\x13 \x01(\x05R\x10\x66rameworkVersion\x12\x17\n\x07web_url\x18\x19 \x01(\tR\x06webUrlB\x13\n\x11\x66\x65\x61ture_view_type\"\xbf\x02\n\x14NewTemporalAggregate\x12@\n\x0eslide_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\rslideInterval\x12\x32\n\x15slide_interval_string\x18\x05 \x01(\tR\x13slideIntervalString\x12?\n\x08\x66\x65\x61tures\x18\x02 \x03(\x0b\x32#.tecton_proto.data.AggregateFeatureR\x08\x66\x65\x61tures\x12#\n\ris_continuous\x18\x03 \x01(\x08R\x0cisContinuous\x12K\n\x10\x64\x61ta_source_type\x18\x04 \x01(\x0e\x32!.tecton_proto.args.DataSourceTypeR\x0e\x64\x61taSourceType\"\xc2\x02\n\x10\x41ggregateFeature\x12,\n\x12input_feature_name\x18\x01 \x01(\tR\x10inputFeatureName\x12.\n\x13output_feature_name\x18\x02 \x01(\tR\x11outputFeatureName\x12\x44\n\x08\x66unction\x18\x03 \x01(\x0e\x32(.tecton_proto.common.AggregationFunctionR\x08\x66unction\x12W\n\x0f\x66unction_params\x18\x05 \x01(\x0b\x32..tecton_proto.common.AggregationFunctionParamsR\x0e\x66unctionParams\x12\x31\n\x06window\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x06window\"\xf5\x01\n\x1dTrailingTimeWindowAggregation\x12\x19\n\x08time_key\x18\x01 \x01(\tR\x07timeKey\x12S\n\x18\x61ggregation_slide_period\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x16\x61ggregationSlidePeriod\x12?\n\x08\x66\x65\x61tures\x18\x03 \x03(\x0b\x32#.tecton_proto.data.AggregateFeatureR\x08\x66\x65\x61tures\x12#\n\ris_continuous\x18\x04 \x01(\x08R\x0cisContinuous\"\xff\x01\n\x0bNewTemporal\x12:\n\x0bserving_ttl\x18\x10 \x01(\x0b\x32\x19.google.protobuf.DurationR\nservingTtl\x12K\n\x10\x64\x61ta_source_type\x18\x11 \x01(\x0e\x32!.tecton_proto.args.DataSourceTypeR\x0e\x64\x61taSourceType\x12J\n\x0f\x62\x61\x63kfill_config\x18\x12 \x01(\x0b\x32!.tecton_proto.args.BackfillConfigR\x0e\x62\x61\x63kfillConfig\x12\x1b\n\tis_custom\x18\x13 \x01(\x08R\x08isCustom\"\x9a\x01\n\x0c\x46\x65\x61tureTable\x12%\n\x0eonline_enabled\x18\x01 \x01(\x08R\ronlineEnabled\x12\'\n\x0foffline_enabled\x18\x02 \x01(\x08R\x0eofflineEnabled\x12:\n\x0bserving_ttl\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\nservingTtl\"*\n\x13OnDemandFeatureView\x12\x13\n\x05no_op\x18\x01 \x01(\x08R\x04noOp\"\xa6\x01\n\x12\x46\x65\x61tureViewSchemas\x12<\n\x0bview_schema\x18\x01 \x01(\x0b\x32\x1b.tecton_proto.common.SchemaR\nviewSchema\x12R\n\x16materialization_schema\x18\x02 \x01(\x0b\x32\x1b.tecton_proto.common.SchemaR\x15materializationSchema\"1\n\x12OnlineServingIndex\x12\x1b\n\tjoin_keys\x18\x01 \x03(\tR\x08joinKeys\"\xbe\x02\n\x1eMaterializationStateTransition\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12%\n\x0eonline_enabled\x18\x02 \x01(\x08R\ronlineEnabled\x12\'\n\x0foffline_enabled\x18\x03 \x01(\x08R\x0eofflineEnabled\x12R\n\x17\x66\x65\x61ture_start_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x15\x66\x65\x61tureStartTimestamp\x12>\n\x1bmaterialization_workflow_id\x18\x05 \x01(\x05R\x19materializationWorkflowId\"\xb0\x06\n\x18NewMaterializationParams\x12\x46\n\x11schedule_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x10scheduleInterval\x12\x43\n\x0fstart_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0estartTimestamp\x12^\n\x1emax_batch_aggregation_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x1bmaxBatchAggregationInterval\x12\x33\n\x16writes_to_online_store\x18\x04 \x01(\x08R\x13writesToOnlineStore\x12\x35\n\x17writes_to_offline_store\x18\x05 \x01(\x08R\x14writesToOfflineStore\x12^\n\x14offline_store_config\x18\x06 \x01(\x0b\x32,.tecton_proto.args.OfflineFeatureStoreConfigR\x12offlineStoreConfig\x12U\n\x15\x62\x61tch_materialization\x18\x07 \x01(\x0b\x32 .tecton_proto.args.ClusterConfigR\x14\x62\x61tchMaterialization\x12W\n\x16stream_materialization\x18\x08 \x01(\x0b\x32 .tecton_proto.args.ClusterConfigR\x15streamMaterialization\x12U\n\x19\x61llowed_upstream_lateness\x18\t \x01(\x0b\x32\x19.google.protobuf.DurationR\x17\x61llowedUpstreamLateness\x12T\n\x13online_store_params\x18\n \x01(\x0b\x32$.tecton_proto.data.OnlineStoreParamsR\x11onlineStoreParams\"\xc7\x01\n\x11OnlineStoreParams\x12%\n\x0euser_specified\x18\x01 \x01(\x08R\ruserSpecified\x12@\n\x06\x64ynamo\x18\x02 \x01(\x0b\x32&.tecton_proto.args.DynamoDbOnlineStoreH\x00R\x06\x64ynamo\x12;\n\x05redis\x18\x03 \x01(\x0b\x32#.tecton_proto.args.RedisOnlineStoreH\x00R\x05redisB\x0c\n\nstore_type\"\xe0\x01\n\x10MonitoringParams\x12%\n\x0euser_specified\x18\x01 \x01(\x08R\ruserSpecified\x12+\n\x11monitor_freshness\x18\x02 \x01(\x08R\x10monitorFreshness\x12W\n\x1a\x65xpected_feature_freshness\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x18\x65xpectedFeatureFreshness\x12\x1f\n\x0b\x61lert_email\x18\x04 \x01(\tR\nalertEmail\"\xf5\x02\n\x16\x46\x65\x61tureViewEnrichments\x12\x39\n\x08\x65ntities\x18\x01 \x03(\x0b\x32\x19.tecton_proto.data.EntityB\x02\x18\x01R\x08\x65ntities\x12Z\n\x14virtual_data_sources\x18\x02 \x03(\x0b\x32$.tecton_proto.data.VirtualDataSourceB\x02\x18\x01R\x12virtualDataSources\x12R\n\x0ftransformations\x18\x03 \x03(\x0b\x32$.tecton_proto.data.NewTransformationB\x02\x18\x01R\x0ftransformations\x12S\n\x12\x66p_materialization\x18\x04 \x01(\x0b\x32$.tecton_proto.data.FvMaterializationR\x11\x66pMaterialization\x12\x1b\n\x07web_url\x18\x05 \x01(\tB\x02\x18\x01R\x06webUrl\"?\n\rSnowflakeData\x12.\n\x13snowflake_view_name\x18\x01 \x01(\tR\x11snowflakeViewNameB\x13\n\x0f\x63om.tecton.dataP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_pipeline__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_virtual__data__source__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_feature__view__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_entity__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_aggregation__function__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_virtual__data__source__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_fv__materialization__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_schema__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_new__transformation__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_fco__metadata__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_id__pb2.DESCRIPTOR,])




_FEATUREVIEW = _descriptor.Descriptor(
  name='FeatureView',
  full_name='tecton_proto.data.FeatureView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_view_id', full_name='tecton_proto.data.FeatureView.feature_view_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureViewId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fco_metadata', full_name='tecton_proto.data.FeatureView.fco_metadata', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcoMetadata', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entity_ids', full_name='tecton_proto.data.FeatureView.entity_ids', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='entityIds', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='join_keys', full_name='tecton_proto.data.FeatureView.join_keys', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='joinKeys', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schemas', full_name='tecton_proto.data.FeatureView.schemas', index=4,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='schemas', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrichments', full_name='tecton_proto.data.FeatureView.enrichments', index=5,
      number=1000, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', json_name='enrichments', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temporal_aggregate', full_name='tecton_proto.data.FeatureView.temporal_aggregate', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='temporalAggregate', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temporal', full_name='tecton_proto.data.FeatureView.temporal', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='temporal', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_demand_feature_view', full_name='tecton_proto.data.FeatureView.on_demand_feature_view', index=8,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='onDemandFeatureView', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_table', full_name='tecton_proto.data.FeatureView.feature_table', index=9,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureTable', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_key', full_name='tecton_proto.data.FeatureView.timestamp_key', index=10,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestampKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_serving_index', full_name='tecton_proto.data.FeatureView.online_serving_index', index=11,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='onlineServingIndex', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='tecton_proto.data.FeatureView.pipeline', index=12,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pipeline', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='materialization_params', full_name='tecton_proto.data.FeatureView.materialization_params', index=13,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='materializationParams', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='materialization_enabled', full_name='tecton_proto.data.FeatureView.materialization_enabled', index=14,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='materializationEnabled', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='materialization_state_transitions', full_name='tecton_proto.data.FeatureView.materialization_state_transitions', index=15,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='materializationStateTransitions', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monitoring_params', full_name='tecton_proto.data.FeatureView.monitoring_params', index=16,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='monitoringParams', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_store_format_version', full_name='tecton_proto.data.FeatureView.feature_store_format_version', index=17,
      number=23, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureStoreFormatVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snowflake_data', full_name='tecton_proto.data.FeatureView.snowflake_data', index=18,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='snowflakeData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='framework_version', full_name='tecton_proto.data.FeatureView.framework_version', index=19,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='frameworkVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='web_url', full_name='tecton_proto.data.FeatureView.web_url', index=20,
      number=25, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='webUrl', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='feature_view_type', full_name='tecton_proto.data.FeatureView.feature_view_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=557,
  serialized_end=2031,
)


_NEWTEMPORALAGGREGATE = _descriptor.Descriptor(
  name='NewTemporalAggregate',
  full_name='tecton_proto.data.NewTemporalAggregate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='slide_interval', full_name='tecton_proto.data.NewTemporalAggregate.slide_interval', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='slideInterval', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slide_interval_string', full_name='tecton_proto.data.NewTemporalAggregate.slide_interval_string', index=1,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='slideIntervalString', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='features', full_name='tecton_proto.data.NewTemporalAggregate.features', index=2,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='features', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_continuous', full_name='tecton_proto.data.NewTemporalAggregate.is_continuous', index=3,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isContinuous', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_source_type', full_name='tecton_proto.data.NewTemporalAggregate.data_source_type', index=4,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dataSourceType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2034,
  serialized_end=2353,
)


_AGGREGATEFEATURE = _descriptor.Descriptor(
  name='AggregateFeature',
  full_name='tecton_proto.data.AggregateFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_feature_name', full_name='tecton_proto.data.AggregateFeature.input_feature_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='inputFeatureName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_feature_name', full_name='tecton_proto.data.AggregateFeature.output_feature_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='outputFeatureName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='function', full_name='tecton_proto.data.AggregateFeature.function', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='function', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='function_params', full_name='tecton_proto.data.AggregateFeature.function_params', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='functionParams', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='window', full_name='tecton_proto.data.AggregateFeature.window', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='window', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2356,
  serialized_end=2678,
)


_TRAILINGTIMEWINDOWAGGREGATION = _descriptor.Descriptor(
  name='TrailingTimeWindowAggregation',
  full_name='tecton_proto.data.TrailingTimeWindowAggregation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_key', full_name='tecton_proto.data.TrailingTimeWindowAggregation.time_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timeKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aggregation_slide_period', full_name='tecton_proto.data.TrailingTimeWindowAggregation.aggregation_slide_period', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='aggregationSlidePeriod', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='features', full_name='tecton_proto.data.TrailingTimeWindowAggregation.features', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='features', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_continuous', full_name='tecton_proto.data.TrailingTimeWindowAggregation.is_continuous', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isContinuous', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2681,
  serialized_end=2926,
)


_NEWTEMPORAL = _descriptor.Descriptor(
  name='NewTemporal',
  full_name='tecton_proto.data.NewTemporal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serving_ttl', full_name='tecton_proto.data.NewTemporal.serving_ttl', index=0,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='servingTtl', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_source_type', full_name='tecton_proto.data.NewTemporal.data_source_type', index=1,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dataSourceType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backfill_config', full_name='tecton_proto.data.NewTemporal.backfill_config', index=2,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='backfillConfig', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_custom', full_name='tecton_proto.data.NewTemporal.is_custom', index=3,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isCustom', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2929,
  serialized_end=3184,
)


_FEATURETABLE = _descriptor.Descriptor(
  name='FeatureTable',
  full_name='tecton_proto.data.FeatureTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='online_enabled', full_name='tecton_proto.data.FeatureTable.online_enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='onlineEnabled', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offline_enabled', full_name='tecton_proto.data.FeatureTable.offline_enabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='offlineEnabled', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serving_ttl', full_name='tecton_proto.data.FeatureTable.serving_ttl', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='servingTtl', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3187,
  serialized_end=3341,
)


_ONDEMANDFEATUREVIEW = _descriptor.Descriptor(
  name='OnDemandFeatureView',
  full_name='tecton_proto.data.OnDemandFeatureView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='no_op', full_name='tecton_proto.data.OnDemandFeatureView.no_op', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='noOp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3343,
  serialized_end=3385,
)


_FEATUREVIEWSCHEMAS = _descriptor.Descriptor(
  name='FeatureViewSchemas',
  full_name='tecton_proto.data.FeatureViewSchemas',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='view_schema', full_name='tecton_proto.data.FeatureViewSchemas.view_schema', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='viewSchema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='materialization_schema', full_name='tecton_proto.data.FeatureViewSchemas.materialization_schema', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='materializationSchema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3388,
  serialized_end=3554,
)


_ONLINESERVINGINDEX = _descriptor.Descriptor(
  name='OnlineServingIndex',
  full_name='tecton_proto.data.OnlineServingIndex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='join_keys', full_name='tecton_proto.data.OnlineServingIndex.join_keys', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='joinKeys', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3556,
  serialized_end=3605,
)


_MATERIALIZATIONSTATETRANSITION = _descriptor.Descriptor(
  name='MaterializationStateTransition',
  full_name='tecton_proto.data.MaterializationStateTransition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='tecton_proto.data.MaterializationStateTransition.timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_enabled', full_name='tecton_proto.data.MaterializationStateTransition.online_enabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='onlineEnabled', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offline_enabled', full_name='tecton_proto.data.MaterializationStateTransition.offline_enabled', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='offlineEnabled', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_start_timestamp', full_name='tecton_proto.data.MaterializationStateTransition.feature_start_timestamp', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureStartTimestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='materialization_workflow_id', full_name='tecton_proto.data.MaterializationStateTransition.materialization_workflow_id', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='materializationWorkflowId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3608,
  serialized_end=3926,
)


_NEWMATERIALIZATIONPARAMS = _descriptor.Descriptor(
  name='NewMaterializationParams',
  full_name='tecton_proto.data.NewMaterializationParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='schedule_interval', full_name='tecton_proto.data.NewMaterializationParams.schedule_interval', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='scheduleInterval', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_timestamp', full_name='tecton_proto.data.NewMaterializationParams.start_timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='startTimestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_batch_aggregation_interval', full_name='tecton_proto.data.NewMaterializationParams.max_batch_aggregation_interval', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='maxBatchAggregationInterval', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='writes_to_online_store', full_name='tecton_proto.data.NewMaterializationParams.writes_to_online_store', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='writesToOnlineStore', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='writes_to_offline_store', full_name='tecton_proto.data.NewMaterializationParams.writes_to_offline_store', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='writesToOfflineStore', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offline_store_config', full_name='tecton_proto.data.NewMaterializationParams.offline_store_config', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='offlineStoreConfig', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_materialization', full_name='tecton_proto.data.NewMaterializationParams.batch_materialization', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='batchMaterialization', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_materialization', full_name='tecton_proto.data.NewMaterializationParams.stream_materialization', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='streamMaterialization', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_upstream_lateness', full_name='tecton_proto.data.NewMaterializationParams.allowed_upstream_lateness', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='allowedUpstreamLateness', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_store_params', full_name='tecton_proto.data.NewMaterializationParams.online_store_params', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='onlineStoreParams', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3929,
  serialized_end=4745,
)


_ONLINESTOREPARAMS = _descriptor.Descriptor(
  name='OnlineStoreParams',
  full_name='tecton_proto.data.OnlineStoreParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_specified', full_name='tecton_proto.data.OnlineStoreParams.user_specified', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userSpecified', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamo', full_name='tecton_proto.data.OnlineStoreParams.dynamo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dynamo', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redis', full_name='tecton_proto.data.OnlineStoreParams.redis', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='redis', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='store_type', full_name='tecton_proto.data.OnlineStoreParams.store_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4748,
  serialized_end=4947,
)


_MONITORINGPARAMS = _descriptor.Descriptor(
  name='MonitoringParams',
  full_name='tecton_proto.data.MonitoringParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_specified', full_name='tecton_proto.data.MonitoringParams.user_specified', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userSpecified', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monitor_freshness', full_name='tecton_proto.data.MonitoringParams.monitor_freshness', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='monitorFreshness', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expected_feature_freshness', full_name='tecton_proto.data.MonitoringParams.expected_feature_freshness', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='expectedFeatureFreshness', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alert_email', full_name='tecton_proto.data.MonitoringParams.alert_email', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='alertEmail', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4950,
  serialized_end=5174,
)


_FEATUREVIEWENRICHMENTS = _descriptor.Descriptor(
  name='FeatureViewEnrichments',
  full_name='tecton_proto.data.FeatureViewEnrichments',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entities', full_name='tecton_proto.data.FeatureViewEnrichments.entities', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', json_name='entities', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_data_sources', full_name='tecton_proto.data.FeatureViewEnrichments.virtual_data_sources', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', json_name='virtualDataSources', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transformations', full_name='tecton_proto.data.FeatureViewEnrichments.transformations', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', json_name='transformations', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fp_materialization', full_name='tecton_proto.data.FeatureViewEnrichments.fp_materialization', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fpMaterialization', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='web_url', full_name='tecton_proto.data.FeatureViewEnrichments.web_url', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', json_name='webUrl', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5177,
  serialized_end=5550,
)


_SNOWFLAKEDATA = _descriptor.Descriptor(
  name='SnowflakeData',
  full_name='tecton_proto.data.SnowflakeData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='snowflake_view_name', full_name='tecton_proto.data.SnowflakeData.snowflake_view_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='snowflakeViewName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5552,
  serialized_end=5615,
)

_FEATUREVIEW.fields_by_name['feature_view_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_FEATUREVIEW.fields_by_name['fco_metadata'].message_type = tecton__proto_dot_data_dot_fco__metadata__pb2._FCOMETADATA
_FEATUREVIEW.fields_by_name['entity_ids'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_FEATUREVIEW.fields_by_name['schemas'].message_type = _FEATUREVIEWSCHEMAS
_FEATUREVIEW.fields_by_name['enrichments'].message_type = _FEATUREVIEWENRICHMENTS
_FEATUREVIEW.fields_by_name['temporal_aggregate'].message_type = _NEWTEMPORALAGGREGATE
_FEATUREVIEW.fields_by_name['temporal'].message_type = _NEWTEMPORAL
_FEATUREVIEW.fields_by_name['on_demand_feature_view'].message_type = _ONDEMANDFEATUREVIEW
_FEATUREVIEW.fields_by_name['feature_table'].message_type = _FEATURETABLE
_FEATUREVIEW.fields_by_name['online_serving_index'].message_type = _ONLINESERVINGINDEX
_FEATUREVIEW.fields_by_name['pipeline'].message_type = tecton__proto_dot_args_dot_pipeline__pb2._PIPELINE
_FEATUREVIEW.fields_by_name['materialization_params'].message_type = _NEWMATERIALIZATIONPARAMS
_FEATUREVIEW.fields_by_name['materialization_state_transitions'].message_type = _MATERIALIZATIONSTATETRANSITION
_FEATUREVIEW.fields_by_name['monitoring_params'].message_type = _MONITORINGPARAMS
_FEATUREVIEW.fields_by_name['snowflake_data'].message_type = _SNOWFLAKEDATA
_FEATUREVIEW.oneofs_by_name['feature_view_type'].fields.append(
  _FEATUREVIEW.fields_by_name['temporal_aggregate'])
_FEATUREVIEW.fields_by_name['temporal_aggregate'].containing_oneof = _FEATUREVIEW.oneofs_by_name['feature_view_type']
_FEATUREVIEW.oneofs_by_name['feature_view_type'].fields.append(
  _FEATUREVIEW.fields_by_name['temporal'])
_FEATUREVIEW.fields_by_name['temporal'].containing_oneof = _FEATUREVIEW.oneofs_by_name['feature_view_type']
_FEATUREVIEW.oneofs_by_name['feature_view_type'].fields.append(
  _FEATUREVIEW.fields_by_name['on_demand_feature_view'])
_FEATUREVIEW.fields_by_name['on_demand_feature_view'].containing_oneof = _FEATUREVIEW.oneofs_by_name['feature_view_type']
_FEATUREVIEW.oneofs_by_name['feature_view_type'].fields.append(
  _FEATUREVIEW.fields_by_name['feature_table'])
_FEATUREVIEW.fields_by_name['feature_table'].containing_oneof = _FEATUREVIEW.oneofs_by_name['feature_view_type']
_NEWTEMPORALAGGREGATE.fields_by_name['slide_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_NEWTEMPORALAGGREGATE.fields_by_name['features'].message_type = _AGGREGATEFEATURE
_NEWTEMPORALAGGREGATE.fields_by_name['data_source_type'].enum_type = tecton__proto_dot_args_dot_virtual__data__source__pb2._DATASOURCETYPE
_AGGREGATEFEATURE.fields_by_name['function'].enum_type = tecton__proto_dot_common_dot_aggregation__function__pb2._AGGREGATIONFUNCTION
_AGGREGATEFEATURE.fields_by_name['function_params'].message_type = tecton__proto_dot_common_dot_aggregation__function__pb2._AGGREGATIONFUNCTIONPARAMS
_AGGREGATEFEATURE.fields_by_name['window'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TRAILINGTIMEWINDOWAGGREGATION.fields_by_name['aggregation_slide_period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TRAILINGTIMEWINDOWAGGREGATION.fields_by_name['features'].message_type = _AGGREGATEFEATURE
_NEWTEMPORAL.fields_by_name['serving_ttl'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_NEWTEMPORAL.fields_by_name['data_source_type'].enum_type = tecton__proto_dot_args_dot_virtual__data__source__pb2._DATASOURCETYPE
_NEWTEMPORAL.fields_by_name['backfill_config'].message_type = tecton__proto_dot_args_dot_feature__view__pb2._BACKFILLCONFIG
_FEATURETABLE.fields_by_name['serving_ttl'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_FEATUREVIEWSCHEMAS.fields_by_name['view_schema'].message_type = tecton__proto_dot_common_dot_schema__pb2._SCHEMA
_FEATUREVIEWSCHEMAS.fields_by_name['materialization_schema'].message_type = tecton__proto_dot_common_dot_schema__pb2._SCHEMA
_MATERIALIZATIONSTATETRANSITION.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MATERIALIZATIONSTATETRANSITION.fields_by_name['feature_start_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_NEWMATERIALIZATIONPARAMS.fields_by_name['schedule_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_NEWMATERIALIZATIONPARAMS.fields_by_name['start_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_NEWMATERIALIZATIONPARAMS.fields_by_name['max_batch_aggregation_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_NEWMATERIALIZATIONPARAMS.fields_by_name['offline_store_config'].message_type = tecton__proto_dot_args_dot_feature__view__pb2._OFFLINEFEATURESTORECONFIG
_NEWMATERIALIZATIONPARAMS.fields_by_name['batch_materialization'].message_type = tecton__proto_dot_args_dot_feature__view__pb2._CLUSTERCONFIG
_NEWMATERIALIZATIONPARAMS.fields_by_name['stream_materialization'].message_type = tecton__proto_dot_args_dot_feature__view__pb2._CLUSTERCONFIG
_NEWMATERIALIZATIONPARAMS.fields_by_name['allowed_upstream_lateness'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_NEWMATERIALIZATIONPARAMS.fields_by_name['online_store_params'].message_type = _ONLINESTOREPARAMS
_ONLINESTOREPARAMS.fields_by_name['dynamo'].message_type = tecton__proto_dot_args_dot_feature__view__pb2._DYNAMODBONLINESTORE
_ONLINESTOREPARAMS.fields_by_name['redis'].message_type = tecton__proto_dot_args_dot_feature__view__pb2._REDISONLINESTORE
_ONLINESTOREPARAMS.oneofs_by_name['store_type'].fields.append(
  _ONLINESTOREPARAMS.fields_by_name['dynamo'])
_ONLINESTOREPARAMS.fields_by_name['dynamo'].containing_oneof = _ONLINESTOREPARAMS.oneofs_by_name['store_type']
_ONLINESTOREPARAMS.oneofs_by_name['store_type'].fields.append(
  _ONLINESTOREPARAMS.fields_by_name['redis'])
_ONLINESTOREPARAMS.fields_by_name['redis'].containing_oneof = _ONLINESTOREPARAMS.oneofs_by_name['store_type']
_MONITORINGPARAMS.fields_by_name['expected_feature_freshness'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_FEATUREVIEWENRICHMENTS.fields_by_name['entities'].message_type = tecton__proto_dot_data_dot_entity__pb2._ENTITY
_FEATUREVIEWENRICHMENTS.fields_by_name['virtual_data_sources'].message_type = tecton__proto_dot_data_dot_virtual__data__source__pb2._VIRTUALDATASOURCE
_FEATUREVIEWENRICHMENTS.fields_by_name['transformations'].message_type = tecton__proto_dot_data_dot_new__transformation__pb2._NEWTRANSFORMATION
_FEATUREVIEWENRICHMENTS.fields_by_name['fp_materialization'].message_type = tecton__proto_dot_data_dot_fv__materialization__pb2._FVMATERIALIZATION
DESCRIPTOR.message_types_by_name['FeatureView'] = _FEATUREVIEW
DESCRIPTOR.message_types_by_name['NewTemporalAggregate'] = _NEWTEMPORALAGGREGATE
DESCRIPTOR.message_types_by_name['AggregateFeature'] = _AGGREGATEFEATURE
DESCRIPTOR.message_types_by_name['TrailingTimeWindowAggregation'] = _TRAILINGTIMEWINDOWAGGREGATION
DESCRIPTOR.message_types_by_name['NewTemporal'] = _NEWTEMPORAL
DESCRIPTOR.message_types_by_name['FeatureTable'] = _FEATURETABLE
DESCRIPTOR.message_types_by_name['OnDemandFeatureView'] = _ONDEMANDFEATUREVIEW
DESCRIPTOR.message_types_by_name['FeatureViewSchemas'] = _FEATUREVIEWSCHEMAS
DESCRIPTOR.message_types_by_name['OnlineServingIndex'] = _ONLINESERVINGINDEX
DESCRIPTOR.message_types_by_name['MaterializationStateTransition'] = _MATERIALIZATIONSTATETRANSITION
DESCRIPTOR.message_types_by_name['NewMaterializationParams'] = _NEWMATERIALIZATIONPARAMS
DESCRIPTOR.message_types_by_name['OnlineStoreParams'] = _ONLINESTOREPARAMS
DESCRIPTOR.message_types_by_name['MonitoringParams'] = _MONITORINGPARAMS
DESCRIPTOR.message_types_by_name['FeatureViewEnrichments'] = _FEATUREVIEWENRICHMENTS
DESCRIPTOR.message_types_by_name['SnowflakeData'] = _SNOWFLAKEDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeatureView = _reflection.GeneratedProtocolMessageType('FeatureView', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREVIEW,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.FeatureView)
  })
_sym_db.RegisterMessage(FeatureView)

NewTemporalAggregate = _reflection.GeneratedProtocolMessageType('NewTemporalAggregate', (_message.Message,), {
  'DESCRIPTOR' : _NEWTEMPORALAGGREGATE,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.NewTemporalAggregate)
  })
_sym_db.RegisterMessage(NewTemporalAggregate)

AggregateFeature = _reflection.GeneratedProtocolMessageType('AggregateFeature', (_message.Message,), {
  'DESCRIPTOR' : _AGGREGATEFEATURE,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.AggregateFeature)
  })
_sym_db.RegisterMessage(AggregateFeature)

TrailingTimeWindowAggregation = _reflection.GeneratedProtocolMessageType('TrailingTimeWindowAggregation', (_message.Message,), {
  'DESCRIPTOR' : _TRAILINGTIMEWINDOWAGGREGATION,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.TrailingTimeWindowAggregation)
  })
_sym_db.RegisterMessage(TrailingTimeWindowAggregation)

NewTemporal = _reflection.GeneratedProtocolMessageType('NewTemporal', (_message.Message,), {
  'DESCRIPTOR' : _NEWTEMPORAL,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.NewTemporal)
  })
_sym_db.RegisterMessage(NewTemporal)

FeatureTable = _reflection.GeneratedProtocolMessageType('FeatureTable', (_message.Message,), {
  'DESCRIPTOR' : _FEATURETABLE,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.FeatureTable)
  })
_sym_db.RegisterMessage(FeatureTable)

OnDemandFeatureView = _reflection.GeneratedProtocolMessageType('OnDemandFeatureView', (_message.Message,), {
  'DESCRIPTOR' : _ONDEMANDFEATUREVIEW,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.OnDemandFeatureView)
  })
_sym_db.RegisterMessage(OnDemandFeatureView)

FeatureViewSchemas = _reflection.GeneratedProtocolMessageType('FeatureViewSchemas', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREVIEWSCHEMAS,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.FeatureViewSchemas)
  })
_sym_db.RegisterMessage(FeatureViewSchemas)

OnlineServingIndex = _reflection.GeneratedProtocolMessageType('OnlineServingIndex', (_message.Message,), {
  'DESCRIPTOR' : _ONLINESERVINGINDEX,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.OnlineServingIndex)
  })
_sym_db.RegisterMessage(OnlineServingIndex)

MaterializationStateTransition = _reflection.GeneratedProtocolMessageType('MaterializationStateTransition', (_message.Message,), {
  'DESCRIPTOR' : _MATERIALIZATIONSTATETRANSITION,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.MaterializationStateTransition)
  })
_sym_db.RegisterMessage(MaterializationStateTransition)

NewMaterializationParams = _reflection.GeneratedProtocolMessageType('NewMaterializationParams', (_message.Message,), {
  'DESCRIPTOR' : _NEWMATERIALIZATIONPARAMS,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.NewMaterializationParams)
  })
_sym_db.RegisterMessage(NewMaterializationParams)

OnlineStoreParams = _reflection.GeneratedProtocolMessageType('OnlineStoreParams', (_message.Message,), {
  'DESCRIPTOR' : _ONLINESTOREPARAMS,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.OnlineStoreParams)
  })
_sym_db.RegisterMessage(OnlineStoreParams)

MonitoringParams = _reflection.GeneratedProtocolMessageType('MonitoringParams', (_message.Message,), {
  'DESCRIPTOR' : _MONITORINGPARAMS,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.MonitoringParams)
  })
_sym_db.RegisterMessage(MonitoringParams)

FeatureViewEnrichments = _reflection.GeneratedProtocolMessageType('FeatureViewEnrichments', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREVIEWENRICHMENTS,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.FeatureViewEnrichments)
  })
_sym_db.RegisterMessage(FeatureViewEnrichments)

SnowflakeData = _reflection.GeneratedProtocolMessageType('SnowflakeData', (_message.Message,), {
  'DESCRIPTOR' : _SNOWFLAKEDATA,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.SnowflakeData)
  })
_sym_db.RegisterMessage(SnowflakeData)


DESCRIPTOR._options = None
_FEATUREVIEW.fields_by_name['enrichments']._options = None
_FEATUREVIEWENRICHMENTS.fields_by_name['entities']._options = None
_FEATUREVIEWENRICHMENTS.fields_by_name['virtual_data_sources']._options = None
_FEATUREVIEWENRICHMENTS.fields_by_name['transformations']._options = None
_FEATUREVIEWENRICHMENTS.fields_by_name['web_url']._options = None
# @@protoc_insertion_point(module_scope)



from tecton_proto.common import aggregation_function_pb2 as afpb


def get_aggregation_function_name(aggregation_function_enum):
    return afpb.AggregationFunction.Name(aggregation_function_enum).replace("AGGREGATION_FUNCTION_", "").lower()


def get_aggregation_column_prefix_from_column_name(aggregation_function_enum, column_name):
    """
    Get the aggregation column prefix from a given intermediate aggregation result column name.

    For example, Feature view with aggregation function AGGREGATE_FUNCTION_MEAN on input "transactions" produces
    intermediate aggregation result columns of "count_transactions", or "mean_transactions".
        - get_aggregation_column_prefix_from_column_name(AGGREGATE_FUNCTION_MEAN, "count_transactions") => "count"
        - get_aggregation_column_prefix_from_column_name(AGGREGATE_FUNCTION_MEAN, "mean_transactions") => "mean"
        - get_aggregation_column_prefix_from_column_name(AGGREGATE_FUNCTION_MEAN, "lastn_transactions") => raise error
    """
    column_prefixes = AGGREGATION_COLUMN_PREFIX_MAP.get(aggregation_function_enum, None)
    for column_prefix in column_prefixes:
        if column_name.startswith(f"{column_prefix}"):
            return column_prefix
    raise ValueError(
        f"Unsupported prefix for column name '{column_name}' for aggregation function '{get_aggregation_function_name(aggregation_function_enum)}'"
    )


def get_aggregation_column_prefixes(aggregation_function):
    col_names = AGGREGATION_COLUMN_PREFIX_MAP.get(aggregation_function, None)
    if col_names is None:
        raise ValueError(f"Unsupported aggregation function {aggregation_function}")
    return col_names


AGGREGATION_COLUMN_PREFIX_MAP = {
    afpb.AGGREGATION_FUNCTION_SUM: [get_aggregation_function_name(afpb.AGGREGATION_FUNCTION_SUM)],
    afpb.AGGREGATION_FUNCTION_MIN: [get_aggregation_function_name(afpb.AGGREGATION_FUNCTION_MIN)],
    afpb.AGGREGATION_FUNCTION_MAX: [get_aggregation_function_name(afpb.AGGREGATION_FUNCTION_MAX)],
    afpb.AGGREGATION_FUNCTION_COUNT: [get_aggregation_function_name(afpb.AGGREGATION_FUNCTION_COUNT)],
    afpb.AGGREGATION_FUNCTION_LAST: [get_aggregation_function_name(afpb.AGGREGATION_FUNCTION_LAST)],
    afpb.AGGREGATION_FUNCTION_LASTN: [get_aggregation_function_name(afpb.AGGREGATION_FUNCTION_LASTN)],
    afpb.AGGREGATION_FUNCTION_MEAN: [
        get_aggregation_function_name(afpb.AGGREGATION_FUNCTION_MEAN),
        get_aggregation_function_name(afpb.AGGREGATION_FUNCTION_COUNT),
    ],
}



from typing import Callable
from typing import List

import attr
import pyspark
from pyspark.sql import functions
from pyspark.sql.functions import expr

from tecton_proto.common import aggregation_function_pb2 as afpb
from tecton_spark.aggregation_utils import get_aggregation_function_name

# WARNING: If you're changing this class there's a good chance you need to change
# AggregationPlans.java. Please look over that file carefully.


@attr.s(auto_attribs=True)
class AggregationPlan(object):
    # The order of columns must be the same in:
    # * The return list in partial_aggregation_transform
    # * The arguments list in full_aggregation_transform
    # * materialized_column_prefixes
    partial_aggregation_transform: Callable[[pyspark.sql.Column], List[pyspark.sql.Column]]
    full_aggregation_transform: Callable[[List[pyspark.sql.Column], pyspark.sql.window.WindowSpec], pyspark.sql.Column]
    materialized_column_prefixes: List[str]

    feature_server_transform: afpb.AggregationFunction

    def materialized_column_names(self, input_column_name):
        return [f"{prefix}_{input_column_name}" for prefix in self.materialized_column_prefixes]


def get_aggregation_plan(aggregation_function, function_params: afpb.AggregationFunctionParams, is_continuous: bool):
    plan = AGGREGATION_PLANS.get(aggregation_function, None)
    if plan is None:
        raise ValueError(f"Unsupported aggregation function {aggregation_function}")

    if callable(plan):
        return plan(function_params, is_continuous)
    else:
        return plan


def _simple_partial_aggregation_transform(spark_transform):
    return lambda col: [spark_transform(col)]


def _simple_full_aggregation_transform(spark_transform):
    return lambda cols, window: spark_transform(cols[0]).over(window)


def _simple_aggregation_plan(aggregation_function: afpb.AggregationFunction, spark_transform):
    return AggregationPlan(
        partial_aggregation_transform=_simple_partial_aggregation_transform(spark_transform),
        full_aggregation_transform=_simple_full_aggregation_transform(spark_transform),
        materialized_column_prefixes=[get_aggregation_function_name(aggregation_function)],
        feature_server_transform=aggregation_function,
    )


from pyspark import SparkContext


def LastNDistinctAgg(col1, col2, n):
    sc = SparkContext._active_spark_context
    udf_name = f"tecton_last_{n}_distinct"
    sc._jvm.com.tecton.udfs.spark3.LastNDistinctRegister().register(n, udf_name)
    return expr(f"{udf_name}({col1}, {col2})")


def LimitedListConcatAgg(col1, n):
    sc = SparkContext._active_spark_context
    udf_name = f"tecton_last_{n}"
    sc._jvm.com.tecton.udfs.spark3.LimitedListConcatRegister().register(n, udf_name)
    return expr(f"{udf_name}({col1})")


def _make_lastn_partial(n: int):
    def _lastn_partial(col):
        return [LastNDistinctAgg("timestamp", col, n)]

    return _lastn_partial


def _make_lastn_full(n: int):
    def _lastn_full(column_name, window):
        col = LimitedListConcatAgg(column_name, n).over(window)
        return col

    return _lastn_full


def _sum_with_default(columns, window):
    col = functions.sum(columns[0]).over(window)
    # Fill null
    col = functions.when(col.isNull(), functions.lit(0)).otherwise(col)
    return col


AGGREGATION_PLANS = {
    afpb.AGGREGATION_FUNCTION_SUM: _simple_aggregation_plan(afpb.AGGREGATION_FUNCTION_SUM, functions.sum),
    afpb.AGGREGATION_FUNCTION_MIN: _simple_aggregation_plan(afpb.AGGREGATION_FUNCTION_MIN, functions.min),
    afpb.AGGREGATION_FUNCTION_MAX: _simple_aggregation_plan(afpb.AGGREGATION_FUNCTION_MAX, functions.max),
    afpb.AGGREGATION_FUNCTION_LAST: _simple_aggregation_plan(
        afpb.AGGREGATION_FUNCTION_LAST, lambda col: functions.last(col, ignorenulls=True)
    ),
    # Needs to use COUNT for partial and SUM for full aggregation
    afpb.AGGREGATION_FUNCTION_COUNT: AggregationPlan(
        partial_aggregation_transform=_simple_partial_aggregation_transform(functions.count),
        full_aggregation_transform=_sum_with_default,
        materialized_column_prefixes=[get_aggregation_function_name(afpb.AGGREGATION_FUNCTION_COUNT)],
        feature_server_transform=afpb.AGGREGATION_FUNCTION_COUNT,
    ),
    afpb.AGGREGATION_FUNCTION_LASTN: lambda params, is_continuous: AggregationPlan(
        partial_aggregation_transform=_make_lastn_partial(params.last_n.n),
        full_aggregation_transform=_make_lastn_full(params.last_n.n),
        materialized_column_prefixes=[
            get_aggregation_function_name(afpb.AGGREGATION_FUNCTION_LASTN)
            + (str(params.last_n.n) if not is_continuous else "")
        ],
        feature_server_transform=afpb.AGGREGATION_FUNCTION_LASTN,
    ),
}


def _mean_full_aggregation(cols, window):
    # Window aggregation doesn't work with more than one built-in function like this
    #   sum(mean_clicked * count_clicked) / sum(count_clicked)
    # And it does not support UDFs on bounded windows (the kind we use)
    #   https://issues.apache.org/jira/browse/SPARK-22239
    # We work around this limitations by calculating ratio over two window aggregations
    mean_col, count_col = cols
    return functions.sum(mean_col * count_col).over(window) / functions.sum(count_col).over(window)


# It is important that `partial_aggregation_transform` or `materialized_column_prefixes`
# contain aggregation data in the same ordering.
AGGREGATION_PLANS[afpb.AGGREGATION_FUNCTION_MEAN] = AggregationPlan(
    partial_aggregation_transform=lambda col: [functions.mean(col), functions.count(col)],
    full_aggregation_transform=_mean_full_aggregation,
    materialized_column_prefixes=[
        get_aggregation_function_name(afpb.AGGREGATION_FUNCTION_MEAN),
        get_aggregation_function_name(afpb.AGGREGATION_FUNCTION_COUNT),
    ],
    feature_server_transform=afpb.AGGREGATION_FUNCTION_MEAN,
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/common/aggregation_function.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/common/aggregation_function.proto',
  package='tecton_proto.common',
  syntax='proto2',
  serialized_options=b'\n\021com.tecton.commonP\001Z(github.com/tecton-ai/tecton_proto/common',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.tecton_proto/common/aggregation_function.proto\x12\x13tecton_proto.common\"\x1b\n\x0bLastNParams\x12\x0c\n\x01n\x18\x01 \x01(\x05R\x01n\"`\n\x19\x41ggregationFunctionParams\x12\x39\n\x06last_n\x18\x01 \x01(\x0b\x32 .tecton_proto.common.LastNParamsH\x00R\x05lastNB\x08\n\x06params*\x9b\x02\n\x13\x41ggregationFunction\x12 \n\x1c\x41GGREGATION_FUNCTION_UNKNOWN\x10\x00\x12\x1e\n\x1a\x41GGREGATION_FUNCTION_COUNT\x10\x01\x12\x1c\n\x18\x41GGREGATION_FUNCTION_SUM\x10\x02\x12\x1d\n\x19\x41GGREGATION_FUNCTION_MEAN\x10\x03\x12\x1d\n\x19\x41GGREGATION_FUNCTION_LAST\x10\x05\x12\x1c\n\x18\x41GGREGATION_FUNCTION_MIN\x10\x06\x12\x1c\n\x18\x41GGREGATION_FUNCTION_MAX\x10\x07\x12\x1e\n\x1a\x41GGREGATION_FUNCTION_LASTN\x10\t\"\x04\x08\x04\x10\x04\"\x04\x08\x08\x10\x08\x42?\n\x11\x63om.tecton.commonP\x01Z(github.com/tecton-ai/tecton_proto/common'
)

_AGGREGATIONFUNCTION = _descriptor.EnumDescriptor(
  name='AggregationFunction',
  full_name='tecton_proto.common.AggregationFunction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AGGREGATION_FUNCTION_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AGGREGATION_FUNCTION_COUNT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AGGREGATION_FUNCTION_SUM', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AGGREGATION_FUNCTION_MEAN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AGGREGATION_FUNCTION_LAST', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AGGREGATION_FUNCTION_MIN', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AGGREGATION_FUNCTION_MAX', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AGGREGATION_FUNCTION_LASTN', index=7, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=199,
  serialized_end=482,
)
_sym_db.RegisterEnumDescriptor(_AGGREGATIONFUNCTION)

AggregationFunction = enum_type_wrapper.EnumTypeWrapper(_AGGREGATIONFUNCTION)
AGGREGATION_FUNCTION_UNKNOWN = 0
AGGREGATION_FUNCTION_COUNT = 1
AGGREGATION_FUNCTION_SUM = 2
AGGREGATION_FUNCTION_MEAN = 3
AGGREGATION_FUNCTION_LAST = 5
AGGREGATION_FUNCTION_MIN = 6
AGGREGATION_FUNCTION_MAX = 7
AGGREGATION_FUNCTION_LASTN = 9



_LASTNPARAMS = _descriptor.Descriptor(
  name='LastNParams',
  full_name='tecton_proto.common.LastNParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='n', full_name='tecton_proto.common.LastNParams.n', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='n', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=98,
)


_AGGREGATIONFUNCTIONPARAMS = _descriptor.Descriptor(
  name='AggregationFunctionParams',
  full_name='tecton_proto.common.AggregationFunctionParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_n', full_name='tecton_proto.common.AggregationFunctionParams.last_n', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='lastN', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='params', full_name='tecton_proto.common.AggregationFunctionParams.params',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=100,
  serialized_end=196,
)

_AGGREGATIONFUNCTIONPARAMS.fields_by_name['last_n'].message_type = _LASTNPARAMS
_AGGREGATIONFUNCTIONPARAMS.oneofs_by_name['params'].fields.append(
  _AGGREGATIONFUNCTIONPARAMS.fields_by_name['last_n'])
_AGGREGATIONFUNCTIONPARAMS.fields_by_name['last_n'].containing_oneof = _AGGREGATIONFUNCTIONPARAMS.oneofs_by_name['params']
DESCRIPTOR.message_types_by_name['LastNParams'] = _LASTNPARAMS
DESCRIPTOR.message_types_by_name['AggregationFunctionParams'] = _AGGREGATIONFUNCTIONPARAMS
DESCRIPTOR.enum_types_by_name['AggregationFunction'] = _AGGREGATIONFUNCTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LastNParams = _reflection.GeneratedProtocolMessageType('LastNParams', (_message.Message,), {
  'DESCRIPTOR' : _LASTNPARAMS,
  '__module__' : 'tecton_proto.common.aggregation_function_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.common.LastNParams)
  })
_sym_db.RegisterMessage(LastNParams)

AggregationFunctionParams = _reflection.GeneratedProtocolMessageType('AggregationFunctionParams', (_message.Message,), {
  'DESCRIPTOR' : _AGGREGATIONFUNCTIONPARAMS,
  '__module__' : 'tecton_proto.common.aggregation_function_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.common.AggregationFunctionParams)
  })
_sym_db.RegisterMessage(AggregationFunctionParams)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



from dataclasses import dataclass
from typing import Union

import pendulum
from pyspark.sql import Column
from pyspark.sql.functions import expr
from pyspark.sql.functions import lit
from typeguard import typechecked

from tecton_spark.errors import TectonValidationError


@dataclass
class BaseMaterializationContext:
    _feature_start_time_DONT_ACCESS_DIRECTLY: pendulum.DateTime
    _feature_end_time_DONT_ACCESS_DIRECTLY: pendulum.DateTime
    _batch_schedule_DONT_ACCESS_DIRECTLY: pendulum.Duration

    @property
    def feature_start_time(self) -> pendulum.DateTime:
        return self._feature_start_time_DONT_ACCESS_DIRECTLY

    @property
    def feature_end_time(self) -> pendulum.DateTime:
        return self._feature_end_time_DONT_ACCESS_DIRECTLY

    @property
    def batch_schedule(self) -> pendulum.Duration:
        return self._batch_schedule_DONT_ACCESS_DIRECTLY

    @property
    def feature_start_time_string(self) -> str:
        return self.feature_start_time.to_datetime_string()

    @property
    def feature_end_time_string(self) -> str:
        return self.feature_end_time.to_datetime_string()

    @typechecked
    def feature_time_filter_sql(self, timestamp_expr: str) -> str:
        return f"('{self.feature_start_time_string}' <= ({timestamp_expr}) AND ({timestamp_expr}) < '{self.feature_end_time_string}')"

    @typechecked
    def feature_time_filter_pyspark(self, timestamp_expr: Union[str, Column]) -> Column:
        if isinstance(timestamp_expr, str):
            timestamp_expr = expr(timestamp_expr)
        return (lit(self.feature_start_time_string) <= timestamp_expr) & (
            timestamp_expr < lit(self.feature_end_time_string)
        )


@dataclass
class UnboundMaterializationContext(BaseMaterializationContext):
    """
    This is only meant for instantiation in transformation default args. Using it directly will fail.
    """

    @property
    def feature_start_time(self):
        raise TectonValidationError(
            "tecton.materialization_context() must be passed in via a kwarg default only. Instantiation in function body is not allowed."
        )

    @property
    def feature_end_time(self):
        raise TectonValidationError(
            "tecton.materialization_context() must be passed in via a kwarg default only. Instantiation in function body is not allowed."
        )

    @property
    def batch_schedule(self):
        raise TectonValidationError(
            "tecton.materialization_context() must be passed in via a kwarg default only. Instantiation in function body is not allowed."
        )


@dataclass
class BoundMaterializationContext(BaseMaterializationContext):
    @classmethod
    def create(cls, feature_start_time, feature_end_time):
        # user facing version
        return BoundMaterializationContext(
            _feature_start_time_DONT_ACCESS_DIRECTLY=feature_start_time,
            _feature_end_time_DONT_ACCESS_DIRECTLY=feature_end_time,
            # batch_schedule is passed by pipeline helper
            _batch_schedule_DONT_ACCESS_DIRECTLY=pendulum.duration(seconds=0),
        )

    @classmethod
    def _create_internal(cls, feature_start_time, feature_end_time, batch_schedule):
        # should only be used in pipeline_helper
        return BoundMaterializationContext(
            _feature_start_time_DONT_ACCESS_DIRECTLY=feature_start_time,
            _feature_end_time_DONT_ACCESS_DIRECTLY=feature_end_time,
            _batch_schedule_DONT_ACCESS_DIRECTLY=batch_schedule,
        )


def materialization_context():
    """
    Used as a default value for the context argument for Transformations that take in a context argument.
    """
    dummy_time = pendulum.datetime(1970, 1, 1)
    dummy_period = pendulum.duration()
    return UnboundMaterializationContext(
        _feature_start_time_DONT_ACCESS_DIRECTLY=dummy_time,
        _feature_end_time_DONT_ACCESS_DIRECTLY=dummy_time,
        _batch_schedule_DONT_ACCESS_DIRECTLY=dummy_period,
    )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/api/featureservice/feature_service_request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from protoc_gen_swagger.options import annotations_pb2 as protoc__gen__swagger_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/api/featureservice/feature_service_request.proto',
  package='tecton_proto.api.feature_service',
  syntax='proto2',
  serialized_options=b'Z4github.com/tecton-ai/tecton_proto/api/featureservice',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=tecton_proto/api/featureservice/feature_service_request.proto\x12 tecton_proto.api.feature_service\x1a\x1cgoogle/protobuf/struct.proto\x1a,protoc-gen-swagger/options/annotations.proto\"\xef\x01\n\x0fMetadataOptions\x12#\n\rinclude_names\x18\x01 \x01(\x08R\x0cincludeNames\x12\x36\n\x17include_effective_times\x18\x02 \x01(\x08R\x15includeEffectiveTimes\x12\'\n\rinclude_types\x18\x03 \x01(\x08\x42\x02\x18\x01R\x0cincludeTypes\x12,\n\x12include_data_types\x18\x05 \x01(\x08R\x10includeDataTypes\x12(\n\x10include_slo_info\x18\x04 \x01(\x08R\x0eincludeSloInfo\"e\n\x12GetFeaturesRequest\x12O\n\x06params\x18\x01 \x01(\x0b\x32\x37.tecton_proto.api.feature_service.GetFeaturesParametersR\x06params\"o\n\x17GetFeaturesBatchRequest\x12T\n\x06params\x18\x01 \x01(\x0b\x32<.tecton_proto.api.feature_service.GetFeaturesBatchParametersR\x06params\"\xf5\x08\n\x15GetFeaturesParameters\x12.\n\x12\x66\x65\x61ture_service_id\x18\x01 \x01(\tH\x00R\x10\x66\x65\x61tureServiceId\x12\x32\n\x14\x66\x65\x61ture_service_name\x18\x02 \x01(\tH\x00R\x12\x66\x65\x61tureServiceName\x12.\n\x12\x66\x65\x61ture_package_id\x18\x0c \x01(\tH\x00R\x10\x66\x65\x61turePackageId\x12\x32\n\x14\x66\x65\x61ture_package_name\x18\r \x01(\tH\x00R\x12\x66\x65\x61turePackageName\x12(\n\x0f\x66\x65\x61ture_view_id\x18\x0f \x01(\tH\x00R\rfeatureViewId\x12,\n\x11\x66\x65\x61ture_view_name\x18\x10 \x01(\tH\x00R\x0f\x66\x65\x61tureViewName\x12%\n\x0eworkspace_name\x18\n \x01(\tR\rworkspaceName\x12i\n\x0cjoin_key_map\x18\x08 \x03(\x0b\x32G.tecton_proto.api.feature_service.GetFeaturesParameters.JoinKeyMapEntryR\njoinKeyMap\x12~\n\x13request_context_map\x18\t \x03(\x0b\x32N.tecton_proto.api.feature_service.GetFeaturesParameters.RequestContextMapEntryR\x11requestContextMap\x12\\\n\x10metadata_options\x18\x07 \x01(\x0b\x32\x31.tecton_proto.api.feature_service.MetadataOptionsR\x0fmetadataOptions\x12>\n\x15\x61llow_partial_results\x18\x0b \x01(\x08\x42\n\x92\x41\x07:\x05\x66\x61lseR\x13\x61llowPartialResults\x1aU\n\x0fJoinKeyMapEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\x1a\\\n\x16RequestContextMapEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01:\xad\x01\x92\x41\xa9\x01\n\x17*\x15GetFeaturesParameters:\x8d\x01{\"feature_service_name\": \"ctr_prediction_service\", \"join_key_map\": { \"ad_id\": \"5417\", \"user_uuid\": \"6c423390-9a64-52c8-9bb3-bbb108c74198\" } }B\t\n\x07locatorJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\x0e\x10\x0f\"\x91\x06\n\x1aGetFeaturesBatchParameters\x12.\n\x12\x66\x65\x61ture_service_id\x18\x01 \x01(\tH\x00R\x10\x66\x65\x61tureServiceId\x12\x32\n\x14\x66\x65\x61ture_service_name\x18\x02 \x01(\tH\x00R\x12\x66\x65\x61tureServiceName\x12%\n\x0eworkspace_name\x18\x03 \x01(\tR\rworkspaceName\x12`\n\x0crequest_data\x18\x04 \x03(\x0b\x32=.tecton_proto.api.feature_service.GetFeaturesBatchRequestDataR\x0brequestData\x12\\\n\x10metadata_options\x18\x05 \x01(\x0b\x32\x31.tecton_proto.api.feature_service.MetadataOptionsR\x0fmetadataOptions:\x9c\x03\x92\x41\x98\x03\n\x1c*\x1aGetFeaturesBatchParameters:\xf7\x02{\"feature_service_name\": \"fraud_detection_feature_service\", \"request_data\": [{\"join_key_map\": { \"user_uuid\": \"6c423390-9a64-52c8-9bb3-bbb108c74198\" },\"request_context_map\": {\"amount\": 2000}},{\"join_key_map\": { \"user_uuid\": \"6c423390-9a64-52c8-9bb3-bbb108c74198\" },\"request_context_map\": {\"amount\": 500}}],\"workspace_name\": \"prod\",\"metadata_options\": {\"include_names\": true} }B\t\n\x07locator\"\xca\x03\n\x1bGetFeaturesBatchRequestData\x12o\n\x0cjoin_key_map\x18\x01 \x03(\x0b\x32M.tecton_proto.api.feature_service.GetFeaturesBatchRequestData.JoinKeyMapEntryR\njoinKeyMap\x12\x84\x01\n\x13request_context_map\x18\x02 \x03(\x0b\x32T.tecton_proto.api.feature_service.GetFeaturesBatchRequestData.RequestContextMapEntryR\x11requestContextMap\x1aU\n\x0fJoinKeyMapEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\x1a\\\n\x16RequestContextMapEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\x42\x36Z4github.com/tecton-ai/tecton_proto/api/featureservice'
  ,
  dependencies=[google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,protoc__gen__swagger_dot_options_dot_annotations__pb2.DESCRIPTOR,])




_METADATAOPTIONS = _descriptor.Descriptor(
  name='MetadataOptions',
  full_name='tecton_proto.api.feature_service.MetadataOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='include_names', full_name='tecton_proto.api.feature_service.MetadataOptions.include_names', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='includeNames', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_effective_times', full_name='tecton_proto.api.feature_service.MetadataOptions.include_effective_times', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='includeEffectiveTimes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_types', full_name='tecton_proto.api.feature_service.MetadataOptions.include_types', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', json_name='includeTypes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_data_types', full_name='tecton_proto.api.feature_service.MetadataOptions.include_data_types', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='includeDataTypes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_slo_info', full_name='tecton_proto.api.feature_service.MetadataOptions.include_slo_info', index=4,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='includeSloInfo', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=176,
  serialized_end=415,
)


_GETFEATURESREQUEST = _descriptor.Descriptor(
  name='GetFeaturesRequest',
  full_name='tecton_proto.api.feature_service.GetFeaturesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='tecton_proto.api.feature_service.GetFeaturesRequest.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='params', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=417,
  serialized_end=518,
)


_GETFEATURESBATCHREQUEST = _descriptor.Descriptor(
  name='GetFeaturesBatchRequest',
  full_name='tecton_proto.api.feature_service.GetFeaturesBatchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='tecton_proto.api.feature_service.GetFeaturesBatchRequest.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='params', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=520,
  serialized_end=631,
)


_GETFEATURESPARAMETERS_JOINKEYMAPENTRY = _descriptor.Descriptor(
  name='JoinKeyMapEntry',
  full_name='tecton_proto.api.feature_service.GetFeaturesParameters.JoinKeyMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.JoinKeyMapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.JoinKeyMapEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1379,
  serialized_end=1464,
)

_GETFEATURESPARAMETERS_REQUESTCONTEXTMAPENTRY = _descriptor.Descriptor(
  name='RequestContextMapEntry',
  full_name='tecton_proto.api.feature_service.GetFeaturesParameters.RequestContextMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.RequestContextMapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.RequestContextMapEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1466,
  serialized_end=1558,
)

_GETFEATURESPARAMETERS = _descriptor.Descriptor(
  name='GetFeaturesParameters',
  full_name='tecton_proto.api.feature_service.GetFeaturesParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_service_id', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.feature_service_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureServiceId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_service_name', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.feature_service_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureServiceName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_package_id', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.feature_package_id', index=2,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featurePackageId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_package_name', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.feature_package_name', index=3,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featurePackageName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view_id', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.feature_view_id', index=4,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureViewId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view_name', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.feature_view_name', index=5,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureViewName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspace_name', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.workspace_name', index=6,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspaceName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='join_key_map', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.join_key_map', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='joinKeyMap', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_context_map', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.request_context_map', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestContextMap', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_options', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.metadata_options', index=9,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='metadataOptions', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_partial_results', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.allow_partial_results', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222A\007:\005false', json_name='allowPartialResults', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETFEATURESPARAMETERS_JOINKEYMAPENTRY, _GETFEATURESPARAMETERS_REQUESTCONTEXTMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\222A\251\001\n\027*\025GetFeaturesParameters:\215\001{\"feature_service_name\": \"ctr_prediction_service\", \"join_key_map\": { \"ad_id\": \"5417\", \"user_uuid\": \"6c423390-9a64-52c8-9bb3-bbb108c74198\" } }',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='locator', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.locator',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=634,
  serialized_end=1775,
)


_GETFEATURESBATCHPARAMETERS = _descriptor.Descriptor(
  name='GetFeaturesBatchParameters',
  full_name='tecton_proto.api.feature_service.GetFeaturesBatchParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_service_id', full_name='tecton_proto.api.feature_service.GetFeaturesBatchParameters.feature_service_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureServiceId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_service_name', full_name='tecton_proto.api.feature_service.GetFeaturesBatchParameters.feature_service_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureServiceName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspace_name', full_name='tecton_proto.api.feature_service.GetFeaturesBatchParameters.workspace_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspaceName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_data', full_name='tecton_proto.api.feature_service.GetFeaturesBatchParameters.request_data', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_options', full_name='tecton_proto.api.feature_service.GetFeaturesBatchParameters.metadata_options', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='metadataOptions', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A\230\003\n\034*\032GetFeaturesBatchParameters:\367\002{\"feature_service_name\": \"fraud_detection_feature_service\", \"request_data\": [{\"join_key_map\": { \"user_uuid\": \"6c423390-9a64-52c8-9bb3-bbb108c74198\" },\"request_context_map\": {\"amount\": 2000}},{\"join_key_map\": { \"user_uuid\": \"6c423390-9a64-52c8-9bb3-bbb108c74198\" },\"request_context_map\": {\"amount\": 500}}],\"workspace_name\": \"prod\",\"metadata_options\": {\"include_names\": true} }',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='locator', full_name='tecton_proto.api.feature_service.GetFeaturesBatchParameters.locator',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1778,
  serialized_end=2563,
)


_GETFEATURESBATCHREQUESTDATA_JOINKEYMAPENTRY = _descriptor.Descriptor(
  name='JoinKeyMapEntry',
  full_name='tecton_proto.api.feature_service.GetFeaturesBatchRequestData.JoinKeyMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='tecton_proto.api.feature_service.GetFeaturesBatchRequestData.JoinKeyMapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='tecton_proto.api.feature_service.GetFeaturesBatchRequestData.JoinKeyMapEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1379,
  serialized_end=1464,
)

_GETFEATURESBATCHREQUESTDATA_REQUESTCONTEXTMAPENTRY = _descriptor.Descriptor(
  name='RequestContextMapEntry',
  full_name='tecton_proto.api.feature_service.GetFeaturesBatchRequestData.RequestContextMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='tecton_proto.api.feature_service.GetFeaturesBatchRequestData.RequestContextMapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='tecton_proto.api.feature_service.GetFeaturesBatchRequestData.RequestContextMapEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1466,
  serialized_end=1558,
)

_GETFEATURESBATCHREQUESTDATA = _descriptor.Descriptor(
  name='GetFeaturesBatchRequestData',
  full_name='tecton_proto.api.feature_service.GetFeaturesBatchRequestData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='join_key_map', full_name='tecton_proto.api.feature_service.GetFeaturesBatchRequestData.join_key_map', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='joinKeyMap', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_context_map', full_name='tecton_proto.api.feature_service.GetFeaturesBatchRequestData.request_context_map', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestContextMap', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETFEATURESBATCHREQUESTDATA_JOINKEYMAPENTRY, _GETFEATURESBATCHREQUESTDATA_REQUESTCONTEXTMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2566,
  serialized_end=3024,
)

_GETFEATURESREQUEST.fields_by_name['params'].message_type = _GETFEATURESPARAMETERS
_GETFEATURESBATCHREQUEST.fields_by_name['params'].message_type = _GETFEATURESBATCHPARAMETERS
_GETFEATURESPARAMETERS_JOINKEYMAPENTRY.fields_by_name['value'].message_type = google_dot_protobuf_dot_struct__pb2._VALUE
_GETFEATURESPARAMETERS_JOINKEYMAPENTRY.containing_type = _GETFEATURESPARAMETERS
_GETFEATURESPARAMETERS_REQUESTCONTEXTMAPENTRY.fields_by_name['value'].message_type = google_dot_protobuf_dot_struct__pb2._VALUE
_GETFEATURESPARAMETERS_REQUESTCONTEXTMAPENTRY.containing_type = _GETFEATURESPARAMETERS
_GETFEATURESPARAMETERS.fields_by_name['join_key_map'].message_type = _GETFEATURESPARAMETERS_JOINKEYMAPENTRY
_GETFEATURESPARAMETERS.fields_by_name['request_context_map'].message_type = _GETFEATURESPARAMETERS_REQUESTCONTEXTMAPENTRY
_GETFEATURESPARAMETERS.fields_by_name['metadata_options'].message_type = _METADATAOPTIONS
_GETFEATURESPARAMETERS.oneofs_by_name['locator'].fields.append(
  _GETFEATURESPARAMETERS.fields_by_name['feature_service_id'])
_GETFEATURESPARAMETERS.fields_by_name['feature_service_id'].containing_oneof = _GETFEATURESPARAMETERS.oneofs_by_name['locator']
_GETFEATURESPARAMETERS.oneofs_by_name['locator'].fields.append(
  _GETFEATURESPARAMETERS.fields_by_name['feature_service_name'])
_GETFEATURESPARAMETERS.fields_by_name['feature_service_name'].containing_oneof = _GETFEATURESPARAMETERS.oneofs_by_name['locator']
_GETFEATURESPARAMETERS.oneofs_by_name['locator'].fields.append(
  _GETFEATURESPARAMETERS.fields_by_name['feature_package_id'])
_GETFEATURESPARAMETERS.fields_by_name['feature_package_id'].containing_oneof = _GETFEATURESPARAMETERS.oneofs_by_name['locator']
_GETFEATURESPARAMETERS.oneofs_by_name['locator'].fields.append(
  _GETFEATURESPARAMETERS.fields_by_name['feature_package_name'])
_GETFEATURESPARAMETERS.fields_by_name['feature_package_name'].containing_oneof = _GETFEATURESPARAMETERS.oneofs_by_name['locator']
_GETFEATURESPARAMETERS.oneofs_by_name['locator'].fields.append(
  _GETFEATURESPARAMETERS.fields_by_name['feature_view_id'])
_GETFEATURESPARAMETERS.fields_by_name['feature_view_id'].containing_oneof = _GETFEATURESPARAMETERS.oneofs_by_name['locator']
_GETFEATURESPARAMETERS.oneofs_by_name['locator'].fields.append(
  _GETFEATURESPARAMETERS.fields_by_name['feature_view_name'])
_GETFEATURESPARAMETERS.fields_by_name['feature_view_name'].containing_oneof = _GETFEATURESPARAMETERS.oneofs_by_name['locator']
_GETFEATURESBATCHPARAMETERS.fields_by_name['request_data'].message_type = _GETFEATURESBATCHREQUESTDATA
_GETFEATURESBATCHPARAMETERS.fields_by_name['metadata_options'].message_type = _METADATAOPTIONS
_GETFEATURESBATCHPARAMETERS.oneofs_by_name['locator'].fields.append(
  _GETFEATURESBATCHPARAMETERS.fields_by_name['feature_service_id'])
_GETFEATURESBATCHPARAMETERS.fields_by_name['feature_service_id'].containing_oneof = _GETFEATURESBATCHPARAMETERS.oneofs_by_name['locator']
_GETFEATURESBATCHPARAMETERS.oneofs_by_name['locator'].fields.append(
  _GETFEATURESBATCHPARAMETERS.fields_by_name['feature_service_name'])
_GETFEATURESBATCHPARAMETERS.fields_by_name['feature_service_name'].containing_oneof = _GETFEATURESBATCHPARAMETERS.oneofs_by_name['locator']
_GETFEATURESBATCHREQUESTDATA_JOINKEYMAPENTRY.fields_by_name['value'].message_type = google_dot_protobuf_dot_struct__pb2._VALUE
_GETFEATURESBATCHREQUESTDATA_JOINKEYMAPENTRY.containing_type = _GETFEATURESBATCHREQUESTDATA
_GETFEATURESBATCHREQUESTDATA_REQUESTCONTEXTMAPENTRY.fields_by_name['value'].message_type = google_dot_protobuf_dot_struct__pb2._VALUE
_GETFEATURESBATCHREQUESTDATA_REQUESTCONTEXTMAPENTRY.containing_type = _GETFEATURESBATCHREQUESTDATA
_GETFEATURESBATCHREQUESTDATA.fields_by_name['join_key_map'].message_type = _GETFEATURESBATCHREQUESTDATA_JOINKEYMAPENTRY
_GETFEATURESBATCHREQUESTDATA.fields_by_name['request_context_map'].message_type = _GETFEATURESBATCHREQUESTDATA_REQUESTCONTEXTMAPENTRY
DESCRIPTOR.message_types_by_name['MetadataOptions'] = _METADATAOPTIONS
DESCRIPTOR.message_types_by_name['GetFeaturesRequest'] = _GETFEATURESREQUEST
DESCRIPTOR.message_types_by_name['GetFeaturesBatchRequest'] = _GETFEATURESBATCHREQUEST
DESCRIPTOR.message_types_by_name['GetFeaturesParameters'] = _GETFEATURESPARAMETERS
DESCRIPTOR.message_types_by_name['GetFeaturesBatchParameters'] = _GETFEATURESBATCHPARAMETERS
DESCRIPTOR.message_types_by_name['GetFeaturesBatchRequestData'] = _GETFEATURESBATCHREQUESTDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MetadataOptions = _reflection.GeneratedProtocolMessageType('MetadataOptions', (_message.Message,), {
  'DESCRIPTOR' : _METADATAOPTIONS,
  '__module__' : 'tecton_proto.api.featureservice.feature_service_request_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.api.feature_service.MetadataOptions)
  })
_sym_db.RegisterMessage(MetadataOptions)

GetFeaturesRequest = _reflection.GeneratedProtocolMessageType('GetFeaturesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESREQUEST,
  '__module__' : 'tecton_proto.api.featureservice.feature_service_request_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.api.feature_service.GetFeaturesRequest)
  })
_sym_db.RegisterMessage(GetFeaturesRequest)

GetFeaturesBatchRequest = _reflection.GeneratedProtocolMessageType('GetFeaturesBatchRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESBATCHREQUEST,
  '__module__' : 'tecton_proto.api.featureservice.feature_service_request_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.api.feature_service.GetFeaturesBatchRequest)
  })
_sym_db.RegisterMessage(GetFeaturesBatchRequest)

GetFeaturesParameters = _reflection.GeneratedProtocolMessageType('GetFeaturesParameters', (_message.Message,), {

  'JoinKeyMapEntry' : _reflection.GeneratedProtocolMessageType('JoinKeyMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETFEATURESPARAMETERS_JOINKEYMAPENTRY,
    '__module__' : 'tecton_proto.api.featureservice.feature_service_request_pb2'
    # @@protoc_insertion_point(class_scope:tecton_proto.api.feature_service.GetFeaturesParameters.JoinKeyMapEntry)
    })
  ,

  'RequestContextMapEntry' : _reflection.GeneratedProtocolMessageType('RequestContextMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETFEATURESPARAMETERS_REQUESTCONTEXTMAPENTRY,
    '__module__' : 'tecton_proto.api.featureservice.feature_service_request_pb2'
    # @@protoc_insertion_point(class_scope:tecton_proto.api.feature_service.GetFeaturesParameters.RequestContextMapEntry)
    })
  ,
  'DESCRIPTOR' : _GETFEATURESPARAMETERS,
  '__module__' : 'tecton_proto.api.featureservice.feature_service_request_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.api.feature_service.GetFeaturesParameters)
  })
_sym_db.RegisterMessage(GetFeaturesParameters)
_sym_db.RegisterMessage(GetFeaturesParameters.JoinKeyMapEntry)
_sym_db.RegisterMessage(GetFeaturesParameters.RequestContextMapEntry)

GetFeaturesBatchParameters = _reflection.GeneratedProtocolMessageType('GetFeaturesBatchParameters', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESBATCHPARAMETERS,
  '__module__' : 'tecton_proto.api.featureservice.feature_service_request_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.api.feature_service.GetFeaturesBatchParameters)
  })
_sym_db.RegisterMessage(GetFeaturesBatchParameters)

GetFeaturesBatchRequestData = _reflection.GeneratedProtocolMessageType('GetFeaturesBatchRequestData', (_message.Message,), {

  'JoinKeyMapEntry' : _reflection.GeneratedProtocolMessageType('JoinKeyMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETFEATURESBATCHREQUESTDATA_JOINKEYMAPENTRY,
    '__module__' : 'tecton_proto.api.featureservice.feature_service_request_pb2'
    # @@protoc_insertion_point(class_scope:tecton_proto.api.feature_service.GetFeaturesBatchRequestData.JoinKeyMapEntry)
    })
  ,

  'RequestContextMapEntry' : _reflection.GeneratedProtocolMessageType('RequestContextMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETFEATURESBATCHREQUESTDATA_REQUESTCONTEXTMAPENTRY,
    '__module__' : 'tecton_proto.api.featureservice.feature_service_request_pb2'
    # @@protoc_insertion_point(class_scope:tecton_proto.api.feature_service.GetFeaturesBatchRequestData.RequestContextMapEntry)
    })
  ,
  'DESCRIPTOR' : _GETFEATURESBATCHREQUESTDATA,
  '__module__' : 'tecton_proto.api.featureservice.feature_service_request_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.api.feature_service.GetFeaturesBatchRequestData)
  })
_sym_db.RegisterMessage(GetFeaturesBatchRequestData)
_sym_db.RegisterMessage(GetFeaturesBatchRequestData.JoinKeyMapEntry)
_sym_db.RegisterMessage(GetFeaturesBatchRequestData.RequestContextMapEntry)


DESCRIPTOR._options = None
_METADATAOPTIONS.fields_by_name['include_types']._options = None
_GETFEATURESPARAMETERS_JOINKEYMAPENTRY._options = None
_GETFEATURESPARAMETERS_REQUESTCONTEXTMAPENTRY._options = None
_GETFEATURESPARAMETERS.fields_by_name['allow_partial_results']._options = None
_GETFEATURESPARAMETERS._options = None
_GETFEATURESBATCHPARAMETERS._options = None
_GETFEATURESBATCHREQUESTDATA_JOINKEYMAPENTRY._options = None
_GETFEATURESBATCHREQUESTDATA_REQUESTCONTEXTMAPENTRY._options = None
# @@protoc_insertion_point(module_scope)
